@@ -1,3 +1,5 @@
+import sys
+from bossman.errors import BossmanValidationError
 from os import getcwd
 import git
 import argparse
@@ -11,21 +13,29 @@ def init(subparsers: argparse._SubParsersAction):
   parser.set_defaults(func=exec)
 
 def exec(bossman: Bossman, glob, *args, **kwargs):
-  resources = bossman.get_resources(*glob)
+  resources = bossman.get_resources_from_working_copy(*glob)
   if len(resources):
     table = Table()
     table.add_column("Resource")
     table.add_column("Validation")
+    table.add_column("Error")
+    error_recorded = 0
     for resource in resources:
+      error = ""
       try:
         bossman.validate(resource)
         status = ":thumbs_up:"
-      except:
+      except BossmanValidationError as e:
         status = ":thumbs_down:"
+        error = e
+        error_recorded = 1
       table.add_row(
         resource,
         status,
+        error
       )
     print(table)
+    if error_recorded == 1:
+      sys.exit(1)
   else:
     print("No resources to show: check the glob pattern if provided, or the configuration.")
